@@ -5,6 +5,9 @@ password0 = 'passw0rd'
 username1 = 'guest1'
 email1 = 'guest1@example.org'
 password1 = 'passw1rd'
+username2 = 'admin0'
+email2 = 'admin0@example.org'
+password2 = 'passw2rd'
 url0 = 'http://dummy.example.org'
 title0 = 'dummy タイトル'
 description0 = 'This description is dummy sentense.'
